#'
#' Functions, Data Sets and Vignettes to Aid in Learning Principal Components Analysis (PCA)
#'
#' Principal component analysis (PCA) is one of the most widely used data analysis techniques.
#' This package provides a series of vignettes explaining PCA starting from basic concepts.
#' The primary purpose is to serve as a self-study resource for anyone wishing to understand PCA better.
#' A few convenience functions are provided as well.
#'
#' @name LearnPCA-package
#' @aliases LearnPCA-package LearnPCA
#' @author Bryan A. Hanson and David T. Harvey.
#' Maintainer: Bryan A. Hanson \email{hanson@@depauw.edu}
#' @keywords package multivariate
#' @import nnet rpart class
#'
"_PACKAGE"
